# <span class="badge package-variant-panelcfg"></span> canvas

## Objects

 * <span class="badge object-type-class"></span> [BackgroundConfig](./object-BackgroundConfig.md)
 * <span class="badge object-type-enum"></span> [BackgroundImageSize](./object-BackgroundImageSize.md)
 * <span class="badge object-type-class"></span> [CanvasConnection](./object-CanvasConnection.md)
 * <span class="badge object-type-class"></span> [CanvasElementOptions](./object-CanvasElementOptions.md)
 * <span class="badge object-type-class"></span> [CanvasOptionsRoot](./object-CanvasOptionsRoot.md)
 * <span class="badge object-type-class"></span> [ConnectionCoordinates](./object-ConnectionCoordinates.md)
 * <span class="badge object-type-enum"></span> [ConnectionPath](./object-ConnectionPath.md)
 * <span class="badge object-type-class"></span> [Constraint](./object-Constraint.md)
 * <span class="badge object-type-enum"></span> [HorizontalConstraint](./object-HorizontalConstraint.md)
 * <span class="badge object-type-enum"></span> [HttpRequestMethod](./object-HttpRequestMethod.md)
 * <span class="badge object-type-class"></span> [LineConfig](./object-LineConfig.md)
 * <span class="badge object-type-class"></span> [Options](./object-Options.md)
 * <span class="badge object-type-class"></span> [Placement](./object-Placement.md)
 * <span class="badge object-type-enum"></span> [VerticalConstraint](./object-VerticalConstraint.md)
## Builders

 * <span class="badge builder"></span> [BackgroundConfig](./builder-BackgroundConfig.md)
 * <span class="badge builder"></span> [CanvasConnection](./builder-CanvasConnection.md)
 * <span class="badge builder"></span> [CanvasElementOptions](./builder-CanvasElementOptions.md)
 * <span class="badge builder"></span> [CanvasOptionsRoot](./builder-CanvasOptionsRoot.md)
 * <span class="badge builder"></span> [ConnectionCoordinates](./builder-ConnectionCoordinates.md)
 * <span class="badge builder"></span> [Constraint](./builder-Constraint.md)
 * <span class="badge builder"></span> [LineConfig](./builder-LineConfig.md)
 * <span class="badge builder"></span> [Panel](./builder-Panel.md)
 * <span class="badge builder"></span> [Placement](./builder-Placement.md)
## Functions

### <span class="badge function"></span> variant_config

variant_config returns the configuration related to canvas panels.

This configuration describes how to unmarshal it, convert it to code, …

```python
def variant_config() -> variants.PanelcfgConfig
```

